@@ -32,6 +32,10 @@ class Fling(LEAPfactory):
     url = "{{ query }}"
 
 
+class Pandora_App(LEAPfactory):
+    url = "https://tv.pandora.com/cast?{{ query }}"
+
+
 class TicTacToe(LEAPfactory):
     url = "http://www.gstatic.com/eureka/sample/tictactoe/tictactoe.html"
     supported_protocols = ['com.google.chromecast.demo.tictactoe']
